==> etterna-0.65.0.tar.gz: etterna-0.65.0/src/archutils/Darwin/SpecialDirs.cpp <==
#include "global.h"
#include "SpecialDirs.h"
#include "ProductInfo.h"
#include <CoreServices/CoreServices.h>
#include <IOKit/IOKitLib.h>
#include "RageUtil.h"

static void
PathForFolderType(char dir[PATH_MAX], OSType folderType)
{
	FSRef fs;

	if (FSFindFolder(kUserDomain, folderType, kDontCreateFolder, &fs))
		FAIL_M(ssprintf("FSFindFolder(%lu) failed.", folderType));
	if (FSRefMakePath(&fs, (UInt8*)dir, PATH_MAX))
		FAIL_M("FSRefMakePath() failed.");
}

RString
SpecialDirs::GetDesktopDir()
{
	char dir[PATH_MAX];
	PathForFolderType(dir, kDesktopFolderType);
	return RString(ssprintf("%s/" PRODUCT_ID, dir));
}

/*
 * (c) 2011 AJ Kelly
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

==> etterna-0.69.1.tar.gz: etterna-0.69.1/src/archutils/Darwin/SpecialDirs.cpp <==
#include "Etterna/Globals/global.h"
#include "SpecialDirs.h"
#include "Etterna/Globals/ProductInfo.h"
#include <CoreServices/CoreServices.h>
#include <IOKit/IOKitLib.h>
#include "RageUtil/Utils/RageUtil.h"

static void
PathForFolderType(char dir[PATH_MAX], OSType folderType)
{
	FSRef fs;

	if (FSFindFolder(kUserDomain, folderType, kDontCreateFolder, &fs))
		FAIL_M(ssprintf("FSFindFolder(%lu) failed.", folderType));
	if (FSRefMakePath(&fs, (UInt8*)dir, PATH_MAX))
		FAIL_M("FSRefMakePath() failed.");
}

RString
SpecialDirs::GetDesktopDir()
{
	char dir[PATH_MAX];
	PathForFolderType(dir, kDesktopFolderType);
	return RString(ssprintf("%s/" PRODUCT_ID, dir));
}

/*
 * (c) 2011 AJ Kelly
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */
